@@ -6,7 +6,7 @@ use warnings;
 
 use Padre::Wx ();
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 our @ISA     = 'Padre::Document';
 
 # max lines to display in a calltip
@@ -901,7 +901,17 @@ sub get_outline {
 
 1;
 
-# Copyright 2008 Gabor Szabo.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
+__END__
+
+=head1 AUTHOR
+
+Ahmad M. Zawawi, C<< <ahmad.zawawi at gmail.com> >>
+
+Gabor Szabo L<http://szabgab.com/>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2008-2009 Padre Developers as in Perl6.pm
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
\ No newline at end of file
