@@ -3,7 +3,7 @@ package Padre::Plugin::Perl6::Perl6SyntaxCheckerTask;
 use strict;
 use warnings;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 use base 'Padre::Task::SyntaxChecker';
 
@@ -62,18 +62,13 @@ with L<Storable>.
 
 =head1 AUTHOR
 
-Ahmad M. Zawawi C<< <ahmad.zawawi@gmail.com> >>
+Ahmad M. Zawawi, C<< <ahmad.zawawi at gmail.com> >>
+
+Gabor Szabo L<http://szabgab.com/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Gabor Szabo.
+Copyright 2008-2009 Padre Developers as in Perl6.pm
 
 This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
-
-=cut
-
-# Copyright 2008 Gabor Szabo.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
+modify it under the same terms as Perl 5 itself.
\ No newline at end of file
