@@ -3,7 +3,7 @@ package Padre::Plugin::Perl6::Util;
 use strict;
 use warnings;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 our @ISA       = 'Exporter';
 our @EXPORT_OK = qw(get_perl6);
@@ -54,4 +54,19 @@ sub get_libparrot {
 	return $libparrot;
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 AUTHOR
+
+Ahmad M. Zawawi, C<< <ahmad.zawawi at gmail.com> >>
+
+Gabor Szabo L<http://szabgab.com/>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2008-2009 Padre Developers as in Perl6.pm
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
\ No newline at end of file
